Application Programming Interface
=================================

.. autoclass:: mlkernels.Kernel
    :show-inheritance:
    :special-members: __call__

.. autofunction:: mlkernels.pairwise

.. autofunction:: mlkernels.elwise

Kernels
-------

.. autoclass:: mlkernels.EQ
    :show-inheritance:

.. autoclass:: mlkernels.RQ
    :show-inheritance:

.. autoclass:: mlkernels.Matern12
    :show-inheritance:

.. autoclass:: mlkernels.Exp
    :show-inheritance:

.. autoclass:: mlkernels.Matern32
    :show-inheritance:

.. autoclass:: mlkernels.Matern52
    :show-inheritance:

.. autoclass:: mlkernels.Linear
    :show-inheritance:

.. autoclass:: mlkernels.Delta
    :show-inheritance:

.. autoclass:: mlkernels.DecayingKernel
    :show-inheritance:

.. autoclass:: mlkernels.LogKernel
    :show-inheritance:

.. autoclass:: mlkernels.PosteriorKernel
    :show-inheritance:

.. autoclass:: mlkernels.SubspaceKernel
    :show-inheritance:

.. autoclass:: mlkernels.TensorProductKernel
    :show-inheritance:
